@@ -4,7 +4,7 @@ import aiohttp
 class OkexAPIException(Exception):
     def __init__(self, response: aiohttp.ClientResponse, error_msg: str, error_code: str = None, extra=None):
         self.message = error_msg
-        self.error_code = int(error_code)
+        self.error_code = int(error_code) if error_code else None
         self.status_code = response.status
         self.response = response
         self.request = getattr(response, 'request', None)
