@@ -79,7 +79,7 @@ class ReconnectingWebSocket:
             await self.ws.close()
             self.ws = None
         if self._conn:
-            await self._conn.__aexit(exc_type, exc_val, exc_tb)
+            await self._conn.__aexit__(exc_type, exc_val, exc_tb)
         self._reset_flag()
         if self._session:
             await self._session.close()
